import { Component, Injectable, Inject } from '@angular/core';
import { Auction } from './auction';
import {ImageService} from '../image/imageservice.component';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import {AlertComponent} from '../alert/alert.component';
import { AlertService } from '../alert/alert.service';
import {SESSION_STORAGE, WebStorageService} from 'angular-webstorage-service';
import {environment} from '../../environments/environment';
import { MsalService } from '../../services/msal.service';
import { toBase64String } from '@angular/compiler/src/output/source_map';
import { AppInsightsService } from 'src/app/app-insights.service';
@Component({
    selector: 'auction',
    templateUrl: './auction.component.html', 
    providers: [ImageService, AlertService, AlertComponent, MsalService]
})
 
@Injectable({
    providedIn: 'root',
  })

export class AuctionComponent {

    loadingAuction:  boolean;
    auction: Auction=new Auction(0,"","",0,0,new Date(),"",24,0,true,"","","", false);
    submitted = false;

    constructor(@Inject(SESSION_STORAGE) private storage: WebStorageService, private imageService: ImageService,  
    private httpClient: HttpClient, private alertService: AlertService, private msalService: MsalService,
    private appInsights: AppInsightsService){}
    
    public resetFields(){
    this.auction= new Auction(0,"","",0,0,new Date(),"",24,0,true,"","","", false);

    }

    receiveImageEventHandler($event){
        console.log("got the event");
        this.auction.image = encodeURIComponent($event);
        console.log("set the image");   
    }
    
    public createAuction() {

    console.log("Token value from Auction Component " +this.msalService.getToken());
     // console.log("token is "+ this.storage.get("token"));
    this.loadingAuction=true;
    this.auction.userId=this.storage.get("userId"); 
    this.auction.userName = this.storage.get("userName");
    const headerSettings: {[name: string]: string | string[]; } = {};    
    headerSettings['Authorization'] = 'Bearer ' + this.msalService.getToken();
    headerSettings['Content-Type'] = 'application/json';
    const newHeader = new HttpHeaders(headerSettings);
     
    this.httpClient.post(environment.auctionAPI+"/auctions", this.auction, {headers: newHeader}).subscribe(
            (res) => {
             
                var id = res;
                console.log(id);
                this.loadingAuction=false;
                this.alertService.add({"type":"success", "message": "Auction created successfully"});  
                this.resetFields();   
            }, 
            (err) => {
                this.loadingAuction=false;
                console.log(err);
                this.alertService.add({"type":"danger", "message": "Some error occured, please contact Administrator"});  
                this.appInsights.instance.trackException(err);
            });
            
        console.log("Auction is created");

        this.appInsights.instance.trackEvent({name: 'CreatedAuction'});
        this.submitted = true;  
    }

 
}