import { Component, Injectable, Inject } from '@angular/core';
import {ImageService} from '../image/imageservice.component';
import { HttpClient} from '@angular/common/http';
import {AlertComponent} from '../alert/alert.component';
import { ActivatedRoute } from '@angular/router';
import { AlertService } from '../alert/alert.service';
import {SESSION_STORAGE, WebStorageService} from 'angular-webstorage-service';
import {environment} from '../../environments/environment';
import { Auction } from '../auction/auction';
import {AuctionPayment} from '../payment/auctionpayment';
import { AppInsightsService } from 'src/app/app-insights.service';

@Component({
    selector: 'payment',
    templateUrl: './payment.component.html', 
    providers: [ImageService, AlertService, AlertComponent]
})
 
@Injectable({
    providedIn: 'root',
  })

export class PaymentComponent {
 
    loadingPayment:  boolean;
    makeAuctionPayment: boolean;
    auctionPayment: AuctionPayment=new AuctionPayment(0,"","","",0,0);
    auction: Auction =new Auction(0,"","",0,0,null,"",0,0,false,null,"","",false);
  
    auctionId: number=0;
    constructor(@Inject(SESSION_STORAGE) private storage: WebStorageService, private imageService: ImageService,  
    private httpClient: HttpClient, private alertService: AlertService, private route: ActivatedRoute,
    private appInsights: AppInsightsService){}
    
    ngOnInit() {
          this.route.queryParams
          .subscribe(params => {
              console.log(params);
            this.auctionId = params.auction;
            this.loadAuctionDetailbyId();
          });
          this.loadingPayment=false;
          this.makeAuctionPayment=false;
      }
     

    public loadAuctionDetailbyId(){
      this.loadingPayment=true;
      this.httpClient.get(environment.auctionAPI+ "/auctionById/"+this.auctionId).subscribe(
        (res) => {
            this.auction =res[0];       
        }, 
        (err) => {
            console.log(err);
            this.alertService.add({"type":"danger", "message":  "Some error occured, please contact Administrator"});  
            this.appInsights.instance.trackException(err);
        });
        this.loadingPayment=false;
        this.appInsights.instance.trackEvent({name:"LoadedAuctionDetailByIDForPayment"});
    }

    public makePayment() {

      this.makeAuctionPayment=true;
      console.log(this.auctionPayment);
      this.auction.userId=this.storage.get("userId"); 
      this.auction.userName = this.storage.get("userName"); 
      this.auctionPayment.month=Number(this.auctionPayment.month);  
      this.auctionPayment.year=Number(this.auctionPayment.year);
      this.httpClient.post(environment.paymentAPI+"/api/auctionpayments", this.auctionPayment).subscribe(
              (res) => {
                  var id = res;
                  console.log(id);
                  this.alertService.add({"type":"success", "message": "Payment is done successfully"});  
                  this.loadingPayment=false;
              }, 
              (err) => {
                  console.log(err);
                  this.alertService.add({"type":"danger", "message": "Some error occured, please contact Administrator"});  
                  this.loadingPayment=false;
                  this.appInsights.instance.trackException(err);
              });
          this.makeAuctionPayment=false;
          this.appInsights.instance.trackEvent({name:"MadePayment"});
    }

 
}